@@ -892,9 +892,9 @@ def _get_preallocated_maps(
 
         # Use the same step on all dimensions before the last check_ndim.
         if all(s == 1 for s in out_shape[:-check_ndim]):
-            step_signs_list = [(1,)] + step_signs_list
+            step_signs_list = [(1,), *step_signs_list]
         else:
-            step_signs_list = [(-1, 1)] + step_signs_list
+            step_signs_list = [(-1, 1), *step_signs_list]
 
         for step_signs in itertools_product(*step_signs_list):
             for step_size in (1, 2):
@@ -1866,7 +1866,7 @@ class _Linker(LocalLinker):
                 # Nothing should be in storage map after evaluating
                 # each the thunk (specifically the last one)
                 for r, s in storage_map.items():
-                    assert type(s) is list
+                    assert isinstance(s, list)
                     assert s[0] is None
 
                 # store our output variables to their respective storage lists
