@@ -109,7 +109,6 @@ def _contains_cycle(fgraph, orderings):
     # Pass through all the nodes to build visitable, parent_count, and
     # node_to_children
     for var in fgraph.variables:
-
         # this is faster than calling get_parents
         owner = var.owner
         # variables don't appear in orderings, so we don't need to worry
@@ -234,10 +233,11 @@ def fast_inplace_check(fgraph, inputs):
 
     """
     Supervisor = pytensor.compile.function.types.Supervisor
-    protected_inputs = [
-        f.protected for f in fgraph._features if isinstance(f, Supervisor)
-    ]
-    protected_inputs = sum(protected_inputs, [])  # flatten the list
+    protected_inputs = list(
+        itertools.chain.from_iterable(
+            f.protected for f in fgraph._features if isinstance(f, Supervisor)
+        )
+    )
     protected_inputs.extend(fgraph.outputs)
 
     inputs = [
@@ -250,7 +250,7 @@ def fast_inplace_check(fgraph, inputs):
     return inputs
 
 
-class DestroyHandler(Bookkeeper):  # noqa
+class DestroyHandler(Bookkeeper):
     """
     The DestroyHandler class detects when a graph is impossible to evaluate
     because of aliasing and destructive operations.
@@ -367,9 +367,7 @@ class DestroyHandler(Bookkeeper):  # noqa
             OrderedSet()
         )  # set of Apply instances with non-null destroy_map
         self.view_i = {}  # variable -> variable used in calculation
-        self.view_o = (
-            {}
-        )  # variable -> set of variables that use this one as a direct input
+        self.view_o = {}  # variable -> set of variables that use this one as a direct input
         # clients: how many times does an apply use a given variable
         self.clients = OrderedDict()  # variable -> apply -> ninputs
         self.stale_droot = True
@@ -401,7 +399,7 @@ class DestroyHandler(Bookkeeper):  # noqa
 
             def recursive_destroys_finder(protected_var):
                 # protected_var is the idx'th input of app.
-                for (app, idx) in fgraph.clients[protected_var]:
+                for app, idx in fgraph.clients[protected_var]:
                     if app == "output":
                         continue
                     destroy_maps = app.op.destroy_map.values()
