@@ -16,15 +16,13 @@ from typing import (
 
 import pytensor
 from pytensor.configdefaults import config
-from pytensor.graph.basic import Apply, NoParams, Variable
+from pytensor.graph.basic import Apply, Variable
 from pytensor.graph.utils import (
     MetaObject,
-    MethodNotDefined,
     TestValueError,
     add_tag_trace,
     get_variable_trace_string,
 )
-from pytensor.link.c.params_type import Params, ParamsType
 
 
 if TYPE_CHECKING:
@@ -37,10 +35,7 @@ StorageMapType = dict[Variable, StorageCellType]
 ComputeMapType = dict[Variable, list[bool]]
 InputStorageType = list[StorageCellType]
 OutputStorageType = list[StorageCellType]
-ParamsInputType = Optional[tuple[Any, ...]]
-PerformMethodType = Callable[
-    [Apply, list[Any], OutputStorageType, ParamsInputType], None
-]
+PerformMethodType = Callable[[Apply, list[Any], OutputStorageType], None]
 BasicThunkType = Callable[[], None]
 ThunkCallableType = Callable[
     [PerformMethodType, StorageMapType, ComputeMapType, Apply], None
@@ -202,7 +197,6 @@ class Op(MetaObject):
 
     itypes: Optional[Sequence["Type"]] = None
     otypes: Optional[Sequence["Type"]] = None
-    params_type: Optional[ParamsType] = None
 
     _output_type_depends_on_input_value = False
     """
@@ -426,7 +420,6 @@ class Op(MetaObject):
         node: Apply,
         inputs: Sequence[Any],
         output_storage: OutputStorageType,
-        params: ParamsInputType = None,
     ) -> None:
         """Calculate the function on the inputs and put the variables in the output storage.
 
@@ -442,8 +435,6 @@ class Op(MetaObject):
             these lists).  Each sub-list corresponds to value of each
             `Variable` in :attr:`node.outputs`.  The primary purpose of this method
             is to set the values of these sub-lists.
-        params
-            A tuple containing the values of each entry in :attr:`Op.__props__`.
 
         Notes
         -----
@@ -481,22 +472,6 @@ class Op(MetaObject):
         """
         return True
 
-    def get_params(self, node: Apply) -> Params:
-        """Try to get parameters for the `Op` when :attr:`Op.params_type` is set to a `ParamsType`."""
-        if isinstance(self.params_type, ParamsType):
-            wrapper = self.params_type
-            if not all(hasattr(self, field) for field in wrapper.fields):
-                # Let's print missing attributes for debugging.
-                not_found = tuple(
-                    field for field in wrapper.fields if not hasattr(self, field)
-                )
-                raise AttributeError(
-                    f"{type(self).__name__}: missing attributes {not_found} for ParamsType."
-                )
-            # ParamsType.get_params() will apply filtering to attributes.
-            return self.params_type.get_params(self)
-        raise MethodNotDefined("get_params")
-
     def prepare_node(
         self,
         node: Apply,
@@ -538,34 +513,12 @@ class Op(MetaObject):
         else:
             p = node.op.perform
 
-        params = node.run_params()
-
-        if params is NoParams:
-            # default arguments are stored in the closure of `rval`
-            @is_thunk_type
-            def rval(
-                p=p, i=node_input_storage, o=node_output_storage, n=node, params=None
-            ):
-                r = p(n, [x[0] for x in i], o)
-                for o in node.outputs:
-                    compute_map[o][0] = True
-                return r
-
-        else:
-            params_val = node.params_type.filter(params)
-
-            @is_thunk_type
-            def rval(
-                p=p,
-                i=node_input_storage,
-                o=node_output_storage,
-                n=node,
-                params=params_val,
-            ):
-                r = p(n, [x[0] for x in i], o, params)
-                for o in node.outputs:
-                    compute_map[o][0] = True
-                return r
+        @is_thunk_type
+        def rval(p=p, i=node_input_storage, o=node_output_storage, n=node):
+            r = p(n, [x[0] for x in i], o)
+            for o in node.outputs:
+                compute_map[o][0] = True
+            return r
 
         rval.inputs = node_input_storage
         rval.outputs = node_output_storage
@@ -640,7 +593,7 @@ class _NoPythonOp(Op):
 
     """
 
-    def perform(self, node, inputs, output_storage, params=None):
+    def perform(self, node, inputs, output_storage):
         raise NotImplementedError("No Python implementation is provided by this Op.")
 
 
