@@ -256,7 +256,7 @@ def vectorize_graph(
         import pytensor
         import pytensor.tensor as pt
 
-        from pytensor.graph import vectorize
+        from pytensor.graph import vectorize_graph
 
         # Original graph
         x = pt.vector("x")
@@ -264,7 +264,7 @@ def vectorize_graph(
 
         # Vectorized graph
         new_x = pt.matrix("new_x")
-        new_y = vectorize(y, replace={x: new_x})
+        new_y = vectorize_graph(y, replace={x: new_x})
 
         fn = pytensor.function([new_x], new_y)
         fn([[0, 1, 2], [2, 1, 0]])
@@ -277,7 +277,7 @@ def vectorize_graph(
         import pytensor
         import pytensor.tensor as pt
 
-        from pytensor.graph import vectorize
+        from pytensor.graph import vectorize_graph
 
         # Original graph
         x = pt.vector("x")
@@ -286,7 +286,7 @@ def vectorize_graph(
 
         # Vectorized graph
         new_x = pt.matrix("new_x")
-        [new_y1, new_y2] = vectorize([y1, y2], replace={x: new_x})
+        [new_y1, new_y2] = vectorize_graph([y1, y2], replace={x: new_x})
 
         fn = pytensor.function([new_x], [new_y1, new_y2])
         fn([[-10, 0, 10], [-11, 0, 11]])
@@ -306,6 +306,11 @@ def vectorize_graph(
         vect_inputs = [vect_vars.get(inp, inp) for inp in node.inputs]
         vect_node = vectorize_node(node, *vect_inputs)
         for output, vect_output in zip(node.outputs, vect_node.outputs):
+            if output in vect_vars:
+                # This can happen when some outputs of a multi-output node are given a replacement,
+                # while some of the remaining outputs are still needed in the graph.
+                # We make sure we don't overwrite the provided replacement with the newly vectorized output
+                continue
             vect_vars[output] = vect_output
 
     seq_vect_outputs = [vect_vars[out] for out in seq_outputs]
