@@ -558,18 +558,20 @@ class CLinkerType(CLinkerObject):
 
         """
         return """
-        if (py_%(name)s == Py_None)
-        {
-            %(c_init_code)s
-        }
+        if (py_{name} == Py_None)
+        {{
+            {c_init_code}
+        }}
         else
-        {
-            %(c_extract_code)s
-        }
-        """ % dict(
-            name=name,
-            c_init_code=self.c_init(name, sub),
-            c_extract_code=self.c_extract(name, sub, check_input),
+        {{
+            {c_extract_code}
+        }}
+        """.format(
+            **dict(
+                name=name,
+                c_init_code=self.c_init(name, sub),
+                c_extract_code=self.c_extract(name, sub, check_input),
+            )
         )
 
     def c_cleanup(self, name: str, sub: dict[str, str]) -> str:
