@@ -602,7 +602,7 @@ class Elemwise(OpenMPOp):
 
         if not isinstance(scalar_igrads, (list, tuple)):
             raise TypeError(
-                f"{str(self.scalar_op)}.grad returned {str(type(scalar_igrads))} instead of list or tuple"
+                f"{self.scalar_op!s}.grad returned {type(scalar_igrads)!s} instead of list or tuple"
             )
 
         nd = inputs[0].type.ndim  # this is the same for everyone
@@ -928,16 +928,13 @@ class Elemwise(OpenMPOp):
             # We make the output point to the corresponding input and
             # decrease the reference of whatever the output contained
             # prior to this
-            alloc += (
-                """
-            if (%(oname)s) {
-                Py_XDECREF(%(oname)s);
-            }
-            %(oname)s = %(iname)s;
-            Py_XINCREF(%(oname)s);
-            """
-                % locals()
-            )
+            alloc += """
+            if ({oname}) {{
+                Py_XDECREF({oname});
+            }}
+            {oname} = {iname};
+            Py_XINCREF({oname});
+            """.format(**locals())
             # We alias the scalar variables
             defines += f"#define {oname}_i {iname}_i\n"
             undefs += f"#undef {oname}_i\n"
@@ -960,16 +957,13 @@ class Elemwise(OpenMPOp):
             [f"{s}_i" for s in onames],
             dict(sub, fail=fail),
         )
-        code = (
-            """
-        {
-            %(defines)s
-            %(task_code)s
-            %(undefs)s
-        }
-        """
-            % locals()
-        )
+        code = """
+        {{
+            {defines}
+            {task_code}
+            {undefs}
+        }}
+        """.format(**locals())
 
         loop_orders = orders + [list(range(nnested))] * len(real_onames)
         dtypes = idtypes + list(real_odtypes)
@@ -1001,30 +995,27 @@ class Elemwise(OpenMPOp):
                         if index != "x":
                             preloops.setdefault(j, "")
                             preloops[j] += (
-                                "%%(lv%(i)s)s_iter = (%(dtype)s*)"
-                                "(PyArray_DATA(%%(lv%(i)s)s));\n" % locals()
+                                "%(lv{i})s_iter = ({dtype}*)"
+                                "(PyArray_DATA(%(lv{i})s));\n".format(**locals())
                             ) % sub
                             break
                     else:  # all broadcastable
                         preloops.setdefault(0, "")
                         preloops[0] += (
-                            "%%(lv%(i)s)s_iter = (%(dtype)s*)"
-                            "(PyArray_DATA(%%(lv%(i)s)s));\n" % locals()
+                            "%(lv{i})s_iter = ({dtype}*)"
+                            "(PyArray_DATA(%(lv{i})s));\n".format(**locals())
                         ) % sub
 
                 init_array = preloops.get(0, " ")
-                loop = (
-                    """
-                {
-                  %(defines)s
-                  %(init_array)s
-                  %(task_decl)s
-                  %(task_code)s
-                  %(undefs)s
-                }
-                """
-                    % locals()
-                )
+                loop = """
+                {{
+                  {defines}
+                  {init_array}
+                  {task_decl}
+                  {task_code}
+                  {undefs}
+                }}
+                """.format(**locals())
             else:
                 loop = cgen.make_loop(
                     loop_orders=loop_orders,
@@ -1084,37 +1075,25 @@ class Elemwise(OpenMPOp):
                     index = ""
                     for x, var in zip(inames + onames, inputs + node.outputs):
                         if not all(s == 1 for s in var.type.shape):
-                            contig += (
-                                """
-            dtype_%(x)s * %(x)s_ptr = (dtype_%(x)s*) PyArray_DATA(%(x)s);
-                            """
-                                % locals()
-                            )
-                            index += (
-                                """
-            dtype_%(x)s& %(x)s_i = %(x)s_ptr[i];
-                            """
-                                % locals()
-                            )
+                            contig += """
+            dtype_{x} * {x}_ptr = (dtype_{x}*) PyArray_DATA({x});
+                            """.format(**locals())
+                            index += """
+            dtype_{x}& {x}_i = {x}_ptr[i];
+                            """.format(**locals())
                         else:
-                            contig += (
-                                """
-            dtype_%(x)s& %(x)s_i = ((dtype_%(x)s*) PyArray_DATA(%(x)s))[0];
-                            """
-                                % locals()
-                            )
+                            contig += """
+            dtype_{x}& {x}_i = ((dtype_{x}*) PyArray_DATA({x}))[0];
+                            """.format(**locals())
                     if self.openmp:
                         contig += f"""#pragma omp parallel for if(n>={int(config.openmp_elemwise_minsize)})
                         """
-                    contig += (
-                        """
-                    for(int i=0; i<n; i++){
-                        %(index)s
-                        %(task_code)s;
-                    }
-                    """
-                        % locals()
-                    )
+                    contig += """
+                    for(int i=0; i<n; i++){{
+                        {index}
+                        {task_code};
+                    }}
+                    """.format(**locals())
             if contig is not None:
                 z = list(zip(inames + onames, inputs + node.outputs))
                 all_broadcastable = all(s == 1 for s in var.type.shape)
@@ -1132,16 +1111,13 @@ class Elemwise(OpenMPOp):
                         if not all_broadcastable
                     ]
                 )
-                loop = (
-                    """
-            if((%(cond1)s) || (%(cond2)s)){
-                %(contig)s
-            }else{
-                %(loop)s
-            }
-            """
-                    % locals()
-                )
+                loop = """
+            if(({cond1}) || ({cond2})){{
+                {contig}
+            }}else{{
+                {loop}
+            }}
+            """.format(**locals())
         return decl, checks, alloc, loop, ""
 
     def c_code(self, node, nodename, inames, onames, sub):
