@@ -1,8 +1,9 @@
+import itertools
 import sys
 from collections import defaultdict, deque
 from collections.abc import Generator
-from functools import lru_cache
-from typing import DefaultDict, TypeVar
+from functools import cache
+from typing import TypeVar
 from warnings import warn
 
 import pytensor
@@ -126,7 +127,7 @@ class InplaceElemwiseOptimizer(GraphRewriter):
             "nb_call_replace": 0,
             "nb_call_validate": 0,
             "nb_inconsistent": 0,
-            "ndim": defaultdict(lambda: 0),
+            "ndim": defaultdict(int),
         }
 
         check_each_change = config.tensor__insert_inplace_optimizer_validate_nb
@@ -144,12 +145,12 @@ class InplaceElemwiseOptimizer(GraphRewriter):
         else:
             update_outs = []
 
-        protected_inputs = [
-            f.protected
-            for f in fgraph._features
-            if isinstance(f, pytensor.compile.function.types.Supervisor)
-        ]
-        protected_inputs = sum(protected_inputs, [])  # flatten the list
+        Supervisor = pytensor.compile.function.types.Supervisor
+        protected_inputs = list(
+            itertools.chain.from_iterable(
+                f.protected for f in fgraph._features if isinstance(f, Supervisor)
+            )
+        )
         protected_inputs.extend(fgraph.outputs)
         for node in list(io_toposort(fgraph.inputs, fgraph.outputs)):
             op = node.op
@@ -686,13 +687,13 @@ class FusionOptimizer(GraphRewriter):
             Elemwise Composite before being accessed again in the next iteration.
             """
 
-            FUSEABLE_MAPPING = DefaultDict[Variable, list[Apply]]
-            UNFUSEABLE_MAPPING = DefaultDict[Variable, set[ApplyOrOutput]]
+            FUSEABLE_MAPPING = defaultdict[Variable, list[Apply]]
+            UNFUSEABLE_MAPPING = defaultdict[Variable, set[ApplyOrOutput]]
 
             def initialize_fuseable_mappings(
                 *, fg: FunctionGraph
             ) -> tuple[FUSEABLE_MAPPING, UNFUSEABLE_MAPPING]:
-                @lru_cache(maxsize=None)
+                @cache
                 def elemwise_scalar_op_has_c_code(node: Apply) -> bool:
                     # TODO: This should not play a role in non-c backends!
                     if node.op.scalar_op.supports_c_code(node.inputs, node.outputs):
@@ -754,9 +755,9 @@ class FusionOptimizer(GraphRewriter):
                 VT = TypeVar("VT", list, set)
 
                 def shallow_clone_defaultdict(
-                    d: DefaultDict[KT, VT]
-                ) -> DefaultDict[KT, VT]:
-                    new_dict: DefaultDict[KT, VT] = defaultdict(d.default_factory)
+                    d: defaultdict[KT, VT],
+                ) -> defaultdict[KT, VT]:
+                    new_dict: defaultdict[KT, VT] = defaultdict(d.default_factory)
                     new_dict.update({k: v.copy() for k, v in d.items()})
                     return new_dict
 
@@ -1188,7 +1189,7 @@ def local_careduce_fusion(fgraph, node):
         scalar_fused_output = ps.cast(scalar_fused_output, car_acc_dtype)
 
     fused_scalar_op = ps.Composite(
-        inputs=[carried_car_input] + scalar_elm_inputs, outputs=[scalar_fused_output]
+        inputs=[carried_car_input, *scalar_elm_inputs], outputs=[scalar_fused_output]
     )
 
     # The fused `Op` needs to look and behave like a `BinaryScalarOp`
