@@ -38,7 +38,7 @@ def is_matrix_transpose(x: TensorVariable) -> bool:
         ndims = inp.type.ndim
         if ndims < 2:
             return False
-        transpose_order = tuple(range(ndims - 2)) + (ndims - 1, ndims - 2)
+        transpose_order = (*range(ndims - 2), ndims - 1, ndims - 2)
         return cast(bool, node.op.new_order == transpose_order)
     return False
 
