@@ -51,9 +51,10 @@ class Cholesky(Op):
     __props__ = ("lower", "destructive", "on_error")
     gufunc_signature = "(m,m)->(m,m)"
 
-    def __init__(self, *, lower=True, on_error="raise"):
+    def __init__(self, *, lower=True, check_finite=True, on_error="raise"):
         self.lower = lower
         self.destructive = False
+        self.check_finite = check_finite
         if on_error not in ("raise", "nan"):
             raise ValueError('on_error must be one of "raise" or ""nan"')
         self.on_error = on_error
@@ -70,7 +71,9 @@ class Cholesky(Op):
         x = inputs[0]
         z = outputs[0]
         try:
-            z[0] = scipy.linalg.cholesky(x, lower=self.lower).astype(x.dtype)
+            z[0] = scipy.linalg.cholesky(
+                x, lower=self.lower, check_finite=self.check_finite
+            ).astype(x.dtype)
         except scipy.linalg.LinAlgError:
             if self.on_error == "raise":
                 raise
@@ -129,8 +132,10 @@ class Cholesky(Op):
             return [grad]
 
 
-def cholesky(x, lower=True, on_error="raise"):
-    return Blockwise(Cholesky(lower=lower, on_error=on_error))(x)
+def cholesky(x, lower=True, on_error="raise", check_finite=False):
+    return Blockwise(
+        Cholesky(lower=lower, on_error=on_error, check_finite=check_finite)
+    )(x)
 
 
 class SolveBase(Op):
@@ -330,7 +335,7 @@ def solve_triangular(
         Input data for the right hand side.
     lower : bool, optional
         Use only data contained in the lower triangle of `a`. Default is to use upper triangle.
-    trans: {0, 1, 2, ‘N’, ‘T’, ‘C’}, optional
+    trans: {0, 1, 2, 'N', 'T', 'C'}, optional
         Type of system to solve:
         trans       system
         0 or 'N'    a x = b
@@ -584,14 +589,17 @@ def kron(a, b):
         )
     o = ptm.outer(a, b)
     o = o.reshape(ptb.concatenate((a.shape, b.shape)), ndim=a.ndim + b.ndim)
-    shf = o.dimshuffle(0, 2, 1, *list(range(3, o.ndim)))
+    shf = o.dimshuffle(0, 2, 1, *range(3, o.ndim))
     if shf.ndim == 3:
         shf = o.dimshuffle(1, 0, 2)
         o = shf.flatten()
     else:
         o = shf.reshape(
-            (o.shape[0] * o.shape[2], o.shape[1] * o.shape[3])
-            + tuple(o.shape[i] for i in range(4, o.ndim))
+            (
+                o.shape[0] * o.shape[2],
+                o.shape[1] * o.shape[3],
+                *(o.shape[i] for i in range(4, o.ndim)),
+            )
         )
     return o
 
