@@ -102,16 +102,13 @@ class GetItem(COp):
         x_name, index = inp[0], inp[1]
         output_name = out[0]
         fail = sub["fail"]
-        return (
-            """
-        %(output_name)s = (typeof %(output_name)s) PyList_GetItem( (PyObject*) %(x_name)s, *((npy_int64 *) PyArray_DATA(%(index)s)));
-        if(%(output_name)s == NULL){
-            %(fail)s
-        }
-        Py_INCREF(%(output_name)s);
-        """
-            % locals()
-        )
+        return """
+        {output_name} = (typeof {output_name}) PyList_GetItem( (PyObject*) {x_name}, *((npy_int64 *) PyArray_DATA({index})));
+        if({output_name} == NULL){{
+            {fail}
+        }}
+        Py_INCREF({output_name});
+        """.format(**locals())
 
     def c_code_cache_version(self):
         return (1,)
@@ -172,12 +169,9 @@ class Append(COp):
         output_name = out[0]
         fail = sub["fail"]
         if not self.inplace:
-            init = (
-                """
-            %(output_name)s = (PyListObject*) PyList_GetSlice((PyObject*) %(x_name)s, 0, PyList_GET_SIZE((PyObject*) %(x_name)s)) ;
-            """
-                % locals()
-            )
+            init = """
+            {output_name} = (PyListObject*) PyList_GetSlice((PyObject*) {x_name}, 0, PyList_GET_SIZE((PyObject*) {x_name})) ;
+            """.format(**locals())
         else:
             init = f"""
             {output_name} =  {x_name};
@@ -185,15 +179,14 @@ class Append(COp):
         return (
             init
             + """
-        if(%(output_name)s==NULL){
-                %(fail)s
-        };
-        if(PyList_Append( (PyObject*) %(output_name)s,(PyObject*) %(toAppend)s)){
-            %(fail)s
-        };
-        Py_INCREF(%(output_name)s);
-        """
-            % locals()
+        if({output_name}==NULL){{
+                {fail}
+        }};
+        if(PyList_Append( (PyObject*) {output_name},(PyObject*) {toAppend})){{
+            {fail}
+        }};
+        Py_INCREF({output_name});
+        """.format(**locals())
         )
 
     def c_code_cache_version(self):
@@ -257,12 +250,9 @@ class Extend(COp):
         output_name = out[0]
         fail = sub["fail"]
         if not self.inplace:
-            init = (
-                """
-            %(output_name)s = (PyListObject*) PyList_GetSlice((PyObject*) %(x_name)s, 0, PyList_GET_SIZE((PyObject*) %(x_name)s)) ;
-            """
-                % locals()
-            )
+            init = """
+            {output_name} = (PyListObject*) PyList_GetSlice((PyObject*) {x_name}, 0, PyList_GET_SIZE((PyObject*) {x_name})) ;
+            """.format(**locals())
         else:
             init = f"""
             {output_name} =  {x_name};
@@ -271,18 +261,17 @@ class Extend(COp):
             init
             + """
         int i =0;
-        int length = PyList_GET_SIZE((PyObject*) %(toAppend)s);
-        if(%(output_name)s==NULL){
-                %(fail)s
-        };
-        for(i; i < length; i++){
-            if(PyList_Append( (PyObject*) %(output_name)s,(PyObject*) PyList_GetItem((PyObject*) %(toAppend)s,i))==-1){
-                %(fail)s
-            };
-        }
-        Py_INCREF(%(output_name)s);
-        """
-            % locals()
+        int length = PyList_GET_SIZE((PyObject*) {toAppend});
+        if({output_name}==NULL){{
+                {fail}
+        }};
+        for(i; i < length; i++){{
+            if(PyList_Append( (PyObject*) {output_name},(PyObject*) PyList_GetItem((PyObject*) {toAppend},i))==-1){{
+                {fail}
+            }};
+        }}
+        Py_INCREF({output_name});
+        """.format(**locals())
         )
 
     def c_code_cache_version_(self):
@@ -349,12 +338,9 @@ class Insert(COp):
         output_name = out[0]
         fail = sub["fail"]
         if not self.inplace:
-            init = (
-                """
-            %(output_name)s = (PyListObject*) PyList_GetSlice((PyObject*) %(x_name)s, 0, PyList_GET_SIZE((PyObject*) %(x_name)s)) ;
-            """
-                % locals()
-            )
+            init = """
+            {output_name} = (PyListObject*) PyList_GetSlice((PyObject*) {x_name}, 0, PyList_GET_SIZE((PyObject*) {x_name})) ;
+            """.format(**locals())
         else:
             init = f"""
             {output_name} =  {x_name};
@@ -362,15 +348,14 @@ class Insert(COp):
         return (
             init
             + """
-        if(%(output_name)s==NULL){
-                %(fail)s
-        };
-        if(PyList_Insert((PyObject*) %(output_name)s, *((npy_int64 *) PyArray_DATA(%(index)s)), (PyObject*) %(toInsert)s)==-1){
-            %(fail)s
-        };
-        Py_INCREF(%(output_name)s);
-        """
-            % locals()
+        if({output_name}==NULL){{
+                {fail}
+        }};
+        if(PyList_Insert((PyObject*) {output_name}, *((npy_int64 *) PyArray_DATA({index})), (PyObject*) {toInsert})==-1){{
+            {fail}
+        }};
+        Py_INCREF({output_name});
+        """.format(**locals())
         )
 
     def c_code_cache_version(self):
@@ -481,12 +466,9 @@ class Reverse(COp):
         output_name = out[0]
         fail = sub["fail"]
         if not self.inplace:
-            init = (
-                """
-            %(output_name)s = (PyListObject*) PyList_GetSlice((PyObject*) %(x_name)s, 0, PyList_GET_SIZE((PyObject*) %(x_name)s)) ;
-            """
-                % locals()
-            )
+            init = """
+            {output_name} = (PyListObject*) PyList_GetSlice((PyObject*) {x_name}, 0, PyList_GET_SIZE((PyObject*) {x_name})) ;
+            """.format(**locals())
         else:
             init = f"""
             {output_name} =  {x_name};
@@ -494,15 +476,14 @@ class Reverse(COp):
         return (
             init
             + """
-        if(%(output_name)s==NULL){
-                %(fail)s
-        };
-        if(PyList_Reverse((PyObject*) %(output_name)s)==-1){
-            %(fail)s
-        };
-        Py_INCREF(%(output_name)s);
-        """
-            % locals()
+        if({output_name}==NULL){{
+                {fail}
+        }};
+        if(PyList_Reverse((PyObject*) {output_name})==-1){{
+            {fail}
+        }};
+        Py_INCREF({output_name});
+        """.format(**locals())
         )
 
     def c_code_cache_version(self):
@@ -616,15 +597,12 @@ class Length(COp):
         x_name = inp[0]
         output_name = out[0]
         fail = sub["fail"]
-        return (
-            """
-        if(!%(output_name)s)
-            %(output_name)s=(PyArrayObject*)PyArray_EMPTY(0, NULL, NPY_INT64, 0);
-        ((npy_int64*)PyArray_DATA(%(output_name)s))[0]=PyList_Size((PyObject*)%(x_name)s);
-        Py_INCREF(%(output_name)s);
-        """
-            % locals()
-        )
+        return """
+        if(!{output_name})
+            {output_name}=(PyArrayObject*)PyArray_EMPTY(0, NULL, NPY_INT64, 0);
+        ((npy_int64*)PyArray_DATA({output_name}))[0]=PyList_Size((PyObject*){x_name});
+        Py_INCREF({output_name});
+        """.format(**locals())
 
     def c_code_cache_version(self):
         return (1,)
